The Consumer Credit Appeals Tribunal was established under the Consumer Credit Act 2006 and heard appeals from decisions of the Office of Fair Trading, including decisions to suspend or revoke a consumer credit licence and decisions under the Money Laundering Regulations 2007. In 2009 its functions were transferred to the General Regulatory Chamber of the First-tier Tribunal, which hears appeals against decisions made by government regulatory bodies.
